pub struct Message { /* private fields */ }Implementations
Sourceimpl Message
impl Message
pub fn new(issuer: Issuer, text: impl Into<String>) -> Self
pub fn new_system(system: &str, text: impl Into<String>) -> Self
pub fn new_user(user: &str, text: impl Into<String>) -> Self
pub fn with_context(self, context: bool) -> Self
Sourcepub fn is_context(&self) -> bool
pub fn is_context(&self) -> bool
Indicates if the message is part of a context. Only avaiable for system messages. If backend receives a message is marked as context , it should be treated as a context message. E.g: OpenAI’s role should be “system” instead of “assistant”.
pub fn with_id(self, id: impl Into<String>) -> Self
pub fn with_created_at(self, timestamp: DateTime<Utc>) -> Self
pub fn with_text(self, text: impl Into<String>) -> Self
pub fn with_token_count(self, token_count: usize) -> Self
pub fn set_token_count(&mut self, token_count: usize)
pub fn token_count(&self) -> usize
pub fn id(&self) -> &str
pub fn is_system(&self) -> bool
pub fn issuer(&self) -> &Issuer
pub fn text(&self) -> &str
pub fn created_at(&self) -> DateTime<Utc>
pub fn issuer_str(&self) -> &str
pub fn append(&mut self, text: impl Into<String>)